@@ -1,9 +1,30 @@
+'''
+
+    DynaTMT-py - a python package to process SILAC/TMT proteomics data
+    Copyright (C) 2021  Kevin Klann
+
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
+'''
 from scipy import stats
 from scipy.stats import trim_mean
 import pandas as pd
 import numpy as np
+import warnings
 from numpy.random import random
 random_float = np.random.RandomState(69)
+warnings.filterwarnings("ignore")
 
 class PD_input:
     '''Class containing functions to analyze the default peptide/PSM output from ProteomeDiscoverer. All column names are assumed
@@ -148,7 +169,10 @@ class PD_input:
             pass
         else:
             pass
-        temp_data=temp_data.loc[temp_data['Mean'] > threshold] # set S/N threshold for each PSM
+        if threshold is None:
+            pass
+        else:
+            temp_data=temp_data.loc[temp_data['Mean'] >= threshold] # set S/N threshold for each PSM
         input_file[channels]=temp_data[channels]
         return input_file
 
@@ -536,7 +560,7 @@ class plain_text_input:
         print("Combination done")
         return protein_df[channels]
 
-    def baseline_correction_peptide_return(self,input_file,threshold=5,i_baseline=0,random=None):#TODO Make available for together analyzed data
+    def baseline_correction_peptide_return(self,input_file,threshold=5,i_baseline=0,random=False, include_negatives=False):#TODO Make available for together analyzed data
         print("Baseline correction")
         channels=self.abundances
         MPA = self.mpa
@@ -550,11 +574,15 @@ class plain_text_input:
         temp_data[channels]=temp_data[channels].subtract(baseline,axis='index')
         temp_data['Mean']=temp_data[channels].mean(axis=1)
         
-        if random is None:
+        if (include_negatives==False and random==False):
             temp_data[temp_data < 0]=0 # replace negative abundances with 0
-        else:
+        elif (include_negatives == False and random ==True):
             for channel in channels:
-                temp_data[channel] = np.where(temp_data[channel] < 0, np.random.random(size=len(temp_data)),temp_data[channel])
+                temp_data[channel] = np.where(temp_data[channel] < 0, random_float.random_sample(size=len(temp_data)),temp_data[channel])
+        elif include_negatives == True:
+            pass
+        else:
+            pass
         temp_data=temp_data.loc[temp_data['Mean'] > threshold] # set S/N threshold for each PSM
         input_file[channels]=temp_data[channels]
         return input_file
